==> ejc-supbid-api-3.0.1-20220124.015454-133-sources.jar: com/ejianc/business/supbid/purchase/vo/PurchaseSchemeRecordVO.java <==
package com.ejianc.business.supbid.purchase.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.ejianc.business.supbid.purchase.vo.PurchaseSchemeDetailRecordVO;

/**
 * 设备采购洽商谈判方案记录表
 * 
 * @author generator
 * 
 */
@ApiModel("设备采购洽商谈判方案记录表")
public class PurchaseSchemeRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
    @ApiModelProperty("报价总额")
    private BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal moneyTax;
    @ApiModelProperty("轮数")
    private Integer talkNum;
    
    @ApiModelProperty("设备采购洽商谈判方案明细记录表")
    private List<PurchaseSchemeDetailRecordVO> purchaseSchemeDetailRecordList = new ArrayList<>();

    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 报价总额
     */
    public BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 轮数
     */
    public Integer getTalkNum() {
        return talkNum;
    }

    /**
     * 轮数
     */
    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }
    
     /**
      * 设备采购洽商谈判方案明细记录表
      */
      public List<PurchaseSchemeDetailRecordVO> getPurchaseSchemeDetailRecordList() {
         return purchaseSchemeDetailRecordList;
      }
     /**
      * 设备采购洽商谈判方案明细记录表
      */
     public void setPurchaseSchemeDetailRecordList(List<PurchaseSchemeDetailRecordVO> purchaseSchemeDetailRecordList) {
         this.purchaseSchemeDetailRecordList = purchaseSchemeDetailRecordList;
     }
}

==> ejc-supbid-api-3.0.1-20220307.121922-151-sources.jar: com/ejianc/business/supbid/purchase/vo/PurchaseSchemeRecordVO.java <==
package com.ejianc.business.supbid.purchase.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.ejianc.business.supbid.purchase.vo.PurchaseSchemeDetailRecordVO;

/**
 * 设备采购洽商谈判方案记录表
 * 
 * @author generator
 * 
 */
@ApiModel("设备采购洽商谈判方案记录表")
public class PurchaseSchemeRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
    @ApiModelProperty("报价总额")
    private BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal moneyTax;
    @ApiModelProperty("轮数")
    private Integer talkNum;
    
    @ApiModelProperty("设备采购洽商谈判方案明细记录表")
    private List<PurchaseSchemeDetailRecordVO> purchaseSchemeDetailList = new ArrayList<>();

    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 报价总额
     */
    public BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 轮数
     */
    public Integer getTalkNum() {
        return talkNum;
    }

    /**
     * 轮数
     */
    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }

    public List<PurchaseSchemeDetailRecordVO> getPurchaseSchemeDetailList() {
        return purchaseSchemeDetailList;
    }

    public void setPurchaseSchemeDetailList(List<PurchaseSchemeDetailRecordVO> purchaseSchemeDetailList) {
        this.purchaseSchemeDetailList = purchaseSchemeDetailList;
    }
}
